*Food consumption: Standardizing units for B03 (total consumption), B04 (purchases), B06 (own production), and B07 (gifts)
	
set more off


*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
} 

use "${gsdData}/1-CleanInput/data_f_proc.dta", clear

* Bring in the cluster variable for later use 
merge m:1 hhid using "${gsdData}/1-CleanInput/hh.dta", keepusing(cluster)
assert _merge == 3
drop _merge

* Making sure we only keep in dataset food items
keep if (foodid>=101 & foodid<=917)

/* 	
	The grand plan:
	---------------
	
	0.	Follow up on data cleaning (minor things not worth discussion)
	
	1. 	Convert quantities (B03, B04, B06 and B07) expressed in standard units
		into KG using (standard) equivalences (1kg = 1lt, 1kg = 1000gr, etc.)
	
	2. 	Convert quantities reported in non-standard units using the method
		based on "price relativities" described in the technical note
	   
	3.	Convert remaining quantities expressed in non-standard units using
		best avaialable information and/or best guesses

*/

* -----------------------------------------------------------------------------
* STEP 0: 	a few ad-hoc fixes 
* 			(this can be ignored and/or moved to data_preparation.do)
* -----------------------------------------------------------------------------

foreach i of numlist 3 4 6 7 {
	* item 302 (groundnuts shelled)
	replace S5_B0`i'B=6 if S5_B0`i'B==2 & foodid==302 
	* item 309 (pulse products)
	replace S5_B0`i'B=1 if hhid==850 & foodid==309
	* item 402 (radishes)
	replace S5_B0`i'B=1 if hhid==1169 & foodid==402
	* item 406 (spinach)
	replace S5_B0`i'B=1 if foodid==406 & hhid==743
	* item 413 (eggplant)
	replace S5_B0`i'A=125 if foodid==413 & hhid==1343
	* item 808 (honey)
	replace S5_B0`i'B=1 if S5_B0`i'B==2 & S5_B0`i'A==1 & foodid==808
	* item 810 (sesame oil)
	replace S5_B0`i'B=15 if foodid==810 & hhid==1188
}

* item 402 (radishes)
replace S5_B03B=2 	if foodid==402 & hhid==1169
replace S5_B04A=200 if foodid==402 & hhid==1169
* item 406 (spinach)
replace S5_B04A=125 if foodid==406 & hhid==548 
	

* -----------------------------------------------------------------------------
* STEP 1: CONVERT STANDARD UNITS INTO KG USING (STANDARD) EQUIVALENCES
* -----------------------------------------------------------------------------

levelsof foodid, local(food)
foreach j of local food {
	foreach i of numlist 3 4 6 7 {
		* gram to kg
		qui replace S5_B0`i'A=S5_B0`i'A/1000 	if S5_B0`i'B==2 & foodid == `j'
		qui replace S5_B0`i'B=1					if S5_B0`i'B==2 & foodid == `j'		
		* liter to kg
		qui replace S5_B0`i'A=S5_B0`i'A/1		if S5_B0`i'B==3 & foodid == `j'
		qui replace S5_B0`i'B=1					if S5_B0`i'B==3 & foodid == `j'
		* milliliter to kg
		qui replace S5_B0`i'A=S5_B0`i'A/1000	if S5_B0`i'B==4 & foodid == `j'
		qui replace S5_B0`i'B=1					if S5_B0`i'B==4 & foodid == `j'
		* liter TIN to kg
		qui replace S5_B0`i'A=S5_B0`i'A/1 		if S5_B0`i'B==5 & foodid == `j'
		qui replace S5_B0`i'B=1					if S5_B0`i'B==5 & foodid == `j'
		* 500 ml TIN to kg
		qui replace S5_B0`i'A=S5_B0`i'A/2 		if S5_B0`i'B==6 & foodid == `j'
		qui replace S5_B0`i'B=1					if S5_B0`i'B==6 & foodid == `j'
		* 250 ml TIN to kg
		qui replace S5_B0`i'A=S5_B0`i'A/4 		if S5_B0`i'B==7 & foodid == `j'
		qui replace S5_B0`i'B=1 				if S5_B0`i'B==7 & foodid == `j'
		* large bag to kg
		* 50 kg = 1 large bag according to the questionnaire (English version)
		qui replace S5_B0`i'A=S5_B0`i'A*50 		if S5_B0`i'B==21 & foodid == `j'
		qui replace S5_B0`i'B=1 				if S5_B0`i'B==21 & foodid == `j'	
		* a quarter bag must equal 0.5 times half bag 
		* note: no assumption is made here on the equivalence half bag/kg
		qui replace S5_B0`i'A=S5_B0`i'A/2 		if S5_B0`i'B==24 & foodid == `j'
		qui replace S5_B0`i'B=23 				if S5_B0`i'B==24 & foodid == `j'	
		* drop if missing unit (out-of-range values)
		qui drop if S5_B0`i'B==99
	}
}

* -----------------------------------------------------------------------------
* STEP 2: CONVERT NON-STANDARD UNITS INTO KG USING "PRICE RELATIVITIES"
* -----------------------------------------------------------------------------

* Generate unit values = expenditure / purchased quantity
gen x_purchase = 0
replace x_purchase = S5_B05/1000  if S5_B05_U==1
replace	x_purchase = S5_B05 	  if S5_B05_U==2
replace x_purchase = S5_B05*1000  if S5_B05_U==3
gen uv = x_purchase/S5_B04A

* set minimum no. of obs. for kg to be a reliable basis to
* convert non-standard units into kg
local minobs 2

levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	levelsof S5_B04B if foodid == `f', local(unit)
	foreach u of local unit {
		qui sum uv if foodid == `f' & S5_B04B==1 , d
		local uvkg = r(p50)
		local countkg = r(N)
		qui sum uv if foodid == `f' & S5_B04B==`u', d
		local uv`u' = r(p50)
		local ratio =  `uv`u''/`uvkg'
		foreach i of numlist 3 4 6 7 {
			qui replace S5_B0`i'A=S5_B0`i'A*(`ratio') if !mi(`ratio') & foodid == `f' & S5_B0`i'B==`u' & `countkg' >= `minobs'
			qui replace S5_B0`i'B=1 if !mi(`ratio') & S5_B0`i'B==`u' & foodid == `f' & `countkg' >= `minobs'
		}
	}
}	

* -----------------------------------------------------------------------------
* STEP 3: CONVERT NON-STANDARD UNITS INTO KG USING BEST GUESSES
* -----------------------------------------------------------------------------

* STEP 3A: equivalences are estimated based on "price relativities", 
*		   using the modal measurement unit as a reference measure

* identify items to be dealt with in step 3
levelsof foodid if S5_B04B>1 & !mi(S5_B04B), local(food)
* identify modal measurement units, by food item
egen mode = mode(S5_B04B) if S5_B04B>1 & !mi(S5_B04B), by(foodid) minmode

foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	levelsof S5_B04B if foodid == `f', local(unit)
	foreach u of local unit {
		qui sum mode if S5_B04B>1 & foodid == `f', d
		local mode = r(p50)
		qui sum uv if foodid == `f' & S5_B04B == `mode', d
		local uvmode = r(p50)
		qui sum uv if foodid == `f' & S5_B04B==`u', d
		local uv`u' = r(p50)
		local ratio =  `uv`u''/`uvmode'
		foreach i of numlist 3 4 6 7 {
			qui replace S5_B0`i'A=S5_B0`i'A*(`ratio') if !mi(`ratio') & foodid == `f' & S5_B0`i'B==`u'
			qui replace S5_B0`i'B=`mode' if !mi(`ratio') & S5_B0`i'B==`u' & foodid == `f'
		}
	}
}

* STEP 3B: guess/impose selected conversion rates
* tab foodid if  S5_B04B>1 &!mi( S5_B04B)
foreach i of numlist 3 4 6 7 {
	* item 116
	qui replace S5_B0`i'A=S5_B0`i'A*0.5 		if foodid == 116 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1		if S5_B0`i'B==15 & foodid == 116

	* item 202
	qui replace S5_B0`i'A=S5_B0`i'A*0.250 		if foodid == 202 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 202	
	
	* item 303
	qui replace S5_B0`i'A=S5_B0`i'A*1 		if foodid == 303 & S5_B0`i'B==14
	qui replace S5_B0`i'B=1 if S5_B0`i'B==14 & foodid == 303

	* item 304
	qui replace S5_B0`i'A=S5_B0`i'A*1		 		if foodid == 304 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 		if S5_B0`i'B==15 & foodid == 304

	* item 305
	qui replace S5_B0`i'A=S5_B0`i'A*1		 		if foodid == 305 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 		if S5_B0`i'B==15 & foodid == 305

	* item 414
	qui replace S5_B0`i'A=S5_B0`i'A*0.5 		if foodid == 414 & S5_B0`i'B==13
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==13 & foodid == 414

	* item 415
	qui replace S5_B0`i'A=S5_B0`i'A*1 			if foodid == 415 & S5_B0`i'B==12
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==12 & foodid == 415
	
	* item 416
	qui replace S5_B0`i'A=S5_B0`i'A*1 			if foodid == 416 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 416
	
	* item 503
	qui replace S5_B0`i'A=S5_B0`i'A*1		if foodid == 503 & S5_B0`i'B==31
	qui replace S5_B0`i'B=1 if S5_B0`i'B==31 & foodid == 503

	* item 506
	qui replace S5_B0`i'A=S5_B0`i'A*1		if foodid == 506 & S5_B0`i'B==33
	qui replace S5_B0`i'B=1 if S5_B0`i'B==33 & foodid == 506

	* item 507
	qui replace S5_B0`i'A=S5_B0`i'A*1		if foodid == 507 & S5_B0`i'B==14
	qui replace S5_B0`i'B=1 if S5_B0`i'B==14 & foodid == 507

	* item 509
	qui replace S5_B0`i'A=S5_B0`i'A*1 		if foodid == 509 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 if S5_B0`i'B==15 & foodid == 509

	* item 514
	qui replace S5_B0`i'A=S5_B0`i'A*1 		if foodid == 514 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 if S5_B0`i'B==15 & foodid == 514

	* item 602
	qui replace S5_B0`i'A=S5_B0`i'A*0.200		if foodid == 602 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 602

	* item 603
	qui replace S5_B0`i'A=S5_B0`i'A*0.150		if foodid == 603 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 603

	* item 604
	qui replace S5_B0`i'A=S5_B0`i'A*0.25	if foodid == 604 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 if S5_B0`i'B==15 & foodid == 604

	* item 605
	qui replace S5_B0`i'A=S5_B0`i'A*0.46		if foodid == 605 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 605

	* item 607
	qui replace S5_B0`i'A=S5_B0`i'A*0.64    	if foodid == 607 & S5_B0`i'B==14
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==14 & foodid == 607

	* item 608
	qui replace S5_B0`i'A=S5_B0`i'A*0.75    	if foodid == 608 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 608

	* item 610
	qui replace S5_B0`i'A=S5_B0`i'A*0.15    	if foodid == 610 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 610

	* item 612
	qui replace S5_B0`i'A=S5_B0`i'A*1   	if foodid == 612 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 if S5_B0`i'B==15 & foodid == 612

	* item 704
	qui replace S5_B0`i'A=S5_B0`i'A*1		if foodid == 704 & S5_B0`i'B==32
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==32 & foodid == 704
	
	* item 804
	qui replace S5_B0`i'A=S5_B0`i'A*0.250		if foodid == 804 & S5_B0`i'B==16
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==16 & foodid == 804

	* item 809
	qui replace S5_B0`i'A=S5_B0`i'A*0.5			if foodid == 809 & S5_B0`i'B==15
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==15 & foodid == 809
	
	* item 906
	qui replace S5_B0`i'A=S5_B0`i'A*0.5			if foodid == 906 & S5_B0`i'B==16
	qui replace S5_B0`i'B=1 	if S5_B0`i'B==16 & foodid == 906

	* item 914
	qui replace S5_B0`i'A=S5_B0`i'A*0.5  	if foodid == 914 & S5_B0`i'B==13
	qui replace S5_B0`i'B=1 if S5_B0`i'B==13 & foodid == 914
}

drop uv
drop x_purchase

sort foodid hhid
save "${gsdData}/1-CleanTemp/food_standard.dta", replace

* -----------------------------------------------------------------------------
* Table 1 of the paper
* -----------------------------------------------------------------------------

use "${gsdData}/1-CleanInput/data_f_proc.dta", clear

* Bring in the cluster variable for later use 
merge m:1 hhid using "${gsdData}/1-CleanInput/hh.dta", keepusing(cluster)
assert _merge == 3
drop _merge

* Making sure we only keep in dataset food items
keep if (foodid>=101 & foodid<=917)

* Create categorical variable for measurement units
gen byte utype=. 
replace utype=1 if S5_B03B<=7 | S5_B03B==21
replace utype=2 if S5_B03B==8
replace utype=3 if S5_B03B==9 | S5_B03B==10
replace utype=4 if S5_B03B>=11 & S5_B03B<=13
replace utype=5 if S5_B03B==14 | S5_B03B==15
replace utype=6 if S5_B03B==16
replace utype=7 if S5_B03B>=22 & S5_B03B<=24
replace utype=8 if (S5_B03B>=30 & !mi(S5_B03B)) | (S5_B03B>=17 & S5_B03B<=20)
label var utype "measurement unit"
#delimit ;
label def utype 1 "metric units" 
				2 "basket" 
				3 "pail"
				4 "bunch"
				5 "piece"
				6 "cup"
				7 "bag"
				8 "other" ;
label val utype utype ;
#delimit cr
tab utype, sort matcell(freq) matrow(type)

*qui putexcel A1=("Measurement Unit") B1=("Freq.") C1=("Percent") using Table01.xls, sheet("Measurement Units") modify 
*qui putexcel A2=matrix(type) B2=matrix(freq) C2=matrix(freq/r(N)) using Table01.xls, sheet("Measurement Units") modify 

local rows = rowsof(type)
local row = 2

forvalues j = 1/`rows' {

	local val = type[`j',1]
	local val_lab : label (utype) `val'
 
	local freq_val = freq[`j',1]
 
	local percent_val = `freq_val'/`r(N)'*100
	local percent_val : display %9.2f `percent_val'
 
	*qui putexcel A`row'=("`val_lab'") B`row'=(`freq_val') C`row'=(`percent_val') using Table01.xls, sheet("Measurement Units") modify 
			
	local row = `row' + 1
}
*qui putexcel A`row'=("Total") B`row'=(r(N)) C`row'=(100.00) using Table01.xls, sheet("Measurement Units") modify 

* -----------------------------------------------------------------------------
* Table 2 of the paper
* -----------------------------------------------------------------------------

use "${gsdData}/1-CleanInput/data_f_proc.dta", clear

* Making sure we only keep in dataset food items
keep if (foodid>=101 & foodid<=917)

* -----------------------------------------------------------------------------
* STEP 0: 	a few ad-hoc fixes 
* 			(this can be ignored and/or moved to data_preparation.do)
* -----------------------------------------------------------------------------

foreach i of numlist 3 4 6 7 {
	* item 302 (groundnuts shelled)
	replace S5_B0`i'B=6 if S5_B0`i'B==2 & foodid==302 
	* item 309 (pulse products)
	replace S5_B0`i'B=1 if hhid==850 & foodid==309
	* item 402 (radishes)
	replace S5_B0`i'B=1 if hhid==1169 & foodid==402
	* item 406 (spinach)
	replace S5_B0`i'B=1 if foodid==406 & hhid==743
	* item 413 (eggplant)
	replace S5_B0`i'A=125 if foodid==413 & hhid==1343
	* item 808 (honey)
	replace S5_B0`i'B=1 if S5_B0`i'B==2 & S5_B0`i'A==1 & foodid==808
	* item 810 (sesame oil)
	replace S5_B0`i'B=15 if foodid==810 & hhid==1188
}

* item 402 (radishes)
replace S5_B03B=2 	if foodid==402 & hhid==1169
replace S5_B04A=200 if foodid==402 & hhid==1169
* item 406 (spinach)
replace S5_B04A=125 if foodid==406 & hhid==548 
	
* Generate unit values = expenditure / purchased quantity
gen x_purchase = 0
replace x_purchase = S5_B05/1000  if S5_B05_U==1
replace	x_purchase = S5_B05 	  if S5_B05_U==2
replace x_purchase = S5_B05*1000  if S5_B05_U==3
gen uv = x_purchase/S5_B04A

* Generate table for illustrating item specificity of conversion factors k (see Sec.3.1) *
table S5_B04B if foodid==404, c(median uv count uv) format(%9.1f)
qui tabout S5_B04B if foodid==404 using "${gsdOutput}/Table02.xls", sum c(median uv count uv) f(3c 0c) replace

* -----------------------------------------------------------------------------
* Table 3 of the paper
* -----------------------------------------------------------------------------

* see Table03.xls (handmade)

