*This file creates the food consumption aggregate
	
set more off

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

* ----------------------------------------------------------------------------
* Food consumption (standardized units)

use "${gsdData}/1-CleanTemp/food_standard.dta", clear

* Drop commodities for which quantities are zero and/or missing. 

* Next line reduces sample size from 190k to 27k observations
drop if mi(S5_B03A) & mi(S5_B03B) & mi(S5_B04A) & mi(S5_B04B) & mi(S5_B06A) & mi(S5_B06B) & mi(S5_B07A) & mi(S5_B07B)

/* 	
	The grand plan:
	---------------
	
	1. 	Detect and clean outliers in quantities (B03, B04, B06 and B07)
		
	2. 	Calculate kilocalories/person/day
	   
	3.	Detect and clean outliers in unit values (B04 and B05)
	
	4.  Calculate food consumption aggregate (=B03*unit value)

*/

* ----------------------------------------------------------------------------
* 1. Clean QUANTITIES
* ----------------------------------------------------------------------------

* Idenfity outliers by stratum

* set threshold to identify outliers (here is 95%)
local sigma 1.96

foreach i of numlist 3 4 6 7 {
	
	gen lnB0`i'=ln(S5_B0`i'A)
	
	gen byte flag_`i'=0

	qui levelsof foodid, local(food)
	foreach f of local food {
		
		qui levelsof strata, local(strata)
		foreach s of local strata {

			qui sum lnB0`i' [aw=weight] if S5_B0`i'A>0 & !mi(S5_B0`i'A) & strata == `s' & foodid==`f'
			
			* When the variance of unit value isgreater than zero we detect and delete outliers
			if r(Var) ~= 0 & r(Var) ~=. {
		
				local what: label (foodid) `f'
				dis in yellow "(`f') - `what'"
			
				qui sum lnB0`i' [aw=weight] if S5_B0`i'A>0 & !mi(S5_B0`i'A) & strata == `s' & foodid==`f'
				loc amean_`f' = r(mean)	
				loc asd_`f' = r(sd)
			
				replace  S5_B0`i'A = . if (abs((lnB0`i' - `amean_`f'') / `asd_`f'') > `sigma') & strata == `s' & foodid==`f' & !mi(lnB0`i')
			
				qui replace flag_`i' = 1 if (abs((lnB0`i' - `amean_`f'') / `asd_`f'') > `sigma') & strata == `s' & foodid==`f' & !mi(lnB0`i')
			}	
		}
	}
}

* Distribution of outliers by item
* next line is required otherwise the ":" in the label of item 416
* drive nuts the putexcel command

label define B02 416 "Other vegetable", modify

foreach i of numlist 3 4 6 7 {
	
	tab foodid if flag_`i' == 1, sort matcell(freq) matrow(fooditems)

	* focus on purchases (B04) and send output to excel file outliersB04.xlsx
	if `i' == 4 {
		*qui putexcel A1=("Food item") B1=("Outlying Obs.") C1=("Outlying Obs. (%)") using outliersB0`i', replace
		*qui putexcel A2=matrix(fooditems) B2=matrix(freq) C2=matrix(freq/r(N)) using outliersB0`i', modify

		local rows = rowsof(fooditems)
		local row = 2
 
		forvalues j = 1/`rows' {
 
			local val = fooditems[`j',1]
			local val_lab : label (foodid) `val'
 
			local freq_val = freq[`j',1]
 
			local percent_val = `freq_val'/`r(N)'*100
			local percent_val : display %9.2f `percent_val'
 
			*qui putexcel A`row'=("`val_lab'") B`row'=(`freq_val') C`row'=(`percent_val') using outliersB0`i', modify
			
			local row = `row' + 1
		}
		*qui putexcel A`row'=("Total") B`row'=(r(N)) C`row'=(100.00) using outliersB0`i', modify
	}
}

* Replace outliers
foreach i of numlist 3 4 6 7 {
	qui levelsof foodid, local(food) 
	
	foreach f of local food {
		
		foreach s of local strata {

			local what: label (foodid) `f'
			dis in yellow "(`f') - `what'"

			_pctile S5_B0`i'A [aw=weight] if S5_B0`i'A>0 & strata == `s' & foodid==`f', p(50)
			replace S5_B0`i'A = r(r1) if flag_`i'==1 & S5_B0`i'A==. & strata == `s' & foodid==`f'			

		}
	}
}

drop flag_*

* ----------------------------------------------------------------------------
* 2. Calculate KILOCALORIES
* ----------------------------------------------------------------------------

gen byte fgroup = .
foreach i of numlist 1(1)7 {
	qui replace fgroup = `i' if int(foodid/100)== `i'
}
qui replace fgroup = 8 	if foodid >= 801 & foodid <= 806
qui replace fgroup = 9 	if foodid >= 807 & foodid <= 813
qui replace fgroup = 10 if foodid >= 901 & foodid <= 908
qui replace fgroup = 11 if foodid >= 909 & foodid <= 917

label def fgroup 1 "Cereals" 2 "Roots" 3 "Nuts and pulses" 4 "Vegetables" ///
				 5 "Meat and fish" 6 "Fruits" 7 "Milk products" 8 "Cooked foods" ///
				 9 "Sugar and fats" 10 "Beverages" 11 "Miscellaneous"

label val fgroup fgroup

*save delme, replace

* Load quantity-to-calorie coefficients
preserve
clear
*import excel using "kilocalories_somaliland.xlsx", sheet("Somaliland") cellrange(A1:E111) firstrow
*qui destring _all, replace
*keep food* kcal protein edible
use "${gsdData}/1-CleanInput/kcalcoeff.dta", clear

* summary table (to be copied and pasted into the annex of the report)
table foodidstr, c(mean kcal mean protein) format(%9.0f)
qui tabout foodidstr using "${gsdOutput}/cal_and_prot.xls", c(mean kcal mean protein) sum f(0c) replace

restore

* bring in quantity-to-calorie coefficients
merge m:1 foodid using "${gsdData}/1-CleanInput/kcalcoeff.dta"
drop if mi(hhid) & _merge == 2
drop _merge

gen kcal_tot = S5_B03A*edible*kcal*10
gen kcal_p   = S5_B04A*edible*kcal*10	// purchased
gen kcal_s   = S5_B06A*edible*kcal*10   // self-production
gen kcal_g   = S5_B07A*edible*kcal*10   // gift

gen protein_tot = S5_B03A*edible*protein*10
gen protein_p   = S5_B04A*edible*protein*10	// purchased
gen protein_s   = S5_B06A*edible*protein*10	// self-production
gen protein_g   = S5_B07A*edible*protein*10	// gift

* quick look at distribution of kilocal/person/day and protein/person/day
preserve
	drop kcal
	collapse (sum) kcal_tot kcal_p kcal_s kcal_g protein*, by(hhid)
	drop protein
	drop if mi(hhid)
	merge 1:1 hhid using "${gsdData}/1-CleanInput/hh.dta", keepusing(S1_HHSIZE weight strata region)
	assert _merge == 3
	drop _merge
	ren S1_HHSIZE hsize

	egen kcal_sum = rowtotal(kcal_p kcal_s kcal_g)
	egen protein_sum = rowtotal(protein_p protein_s protein_g)

	* transform in per day and per capita terms
	foreach var of varlist kcal* protein* {
		replace `var' = (`var'/hsize)/7
	}

	save "${gsdData}/1-CleanTemp/kcal_dn.dta", replace

	su kcal* [aw=weight*hsize]
	* rough estimate of incidence of undernutrition
	povdeco kcal_tot [aw=weight*hsize], pl(2000)
	povdeco protein_tot [aw=weight*hsize], pl(55)

	su protein* [aw=weight*hsize]

	xtile kcalven = kcal_tot [aw=weight*hsize], nq(20)
	xtile kcaldec = kcal_tot [aw=weight*hsize], nq(10)
	xtile kcalqui = kcal_tot [aw=weight*hsize], nq(5)
	xtile protqui = protein_tot [aw=weight*hsize], nq(5)

	table kcalven [aw=weight*hsize], c(mean kcal_tot mean kcal_p mean kcal_s  mean kcal_g mean kcal_sum) row format(%9.0f)
	table kcaldec [aw=weight*hsize], c(mean kcal_tot mean kcal_p mean kcal_s  mean kcal_g mean kcal_sum) row format(%9.0f)
	table kcalqui [aw=weight*hsize], c(mean kcal_tot mean kcal_p mean kcal_s mean kcal_g mean kcal_sum) row format(%9.0f)
	table strata  [aw=weight*hsize], c(mean kcal_tot mean kcal_p mean kcal_s mean kcal_g mean kcal_sum) row format(%9.0f)
	table region  [aw=weight*hsize], c(mean kcal_tot mean kcal_p mean kcal_s mean kcal_g mean kcal_sum) row format(%9.0f)
	table protqui [aw=weight*hsize], c(mean protein_tot median protein_tot) row format(%9.0f)
	table strata [aw=weight*hsize], c(mean protein_tot median protein_tot) row format(%9.0f)
	table region [aw=weight*hsize], c(mean protein_tot median protein_tot) row format(%9.0f)
*	kdensity kcal_tot
*	kdensity protein_tot
restore

* composition of kilocalories by source
preserve
drop kcal
keep kcal_tot protein_tot fgroup hhid
fillin hhid fgroup
mvencode kcal_tot protein_tot, mv(0) override

collapse (sum) kcal_tot protein_tot, by(fgroup hhid)

merge m:1 hhid using "${gsdData}/1-CleanInput/hh.dta", keepusing(S1_HHSIZE weight strata region)
assert _merge == 3
drop _merge
ren S1_HHSIZE hsize

* transform in per day and per capita terms
foreach var of varlist kcal_tot protein_tot {
	replace `var' = (`var'/hsize)/7
}

table fgroup [aw=weight*hsize], c(mean kcal_tot median kcal_tot mean protein_tot median protein_tot) format(%9.0f)
*graph bar kcal_tot, over(fgroup, sort(kcal_tot) descending  label( angle(45) labsize(*.7))) over(strata)
restore

* ----------------------------------------------------------------------------
* 3. Generate UNIT VALUES for all purchased food items
* ----------------------------------------------------------------------------

* start from standardized data (NOTE: data *not* cleaned for outliers)
use "${gsdData}/1-CleanTemp/food_standard.dta", clear

* Drop commodities for which quantities are zero and/or missing. 

* Next line reduces sample size from 190k to 27k observations
drop if mi(S5_B03A) & mi(S5_B03B) & mi(S5_B04A) & mi(S5_B04B) & mi(S5_B06A) & mi(S5_B06B) & mi(S5_B07A) & mi(S5_B07B)

* First convert all money spent to same units (thousand of shillings)
* S = 1 shilling
* K = 1,000 shillings
* M = 1,000,000 shillings

gen double x_purchase = 0
replace x_purchase = S5_B05/1000  if S5_B05_U==1
replace	x_purchase = S5_B05 	  if S5_B05_U==2
replace x_purchase = S5_B05*1000  if S5_B05_U==3

* Generate unit values = expenditure/quantity
gen double uv = x_purchase/S5_B04A

* Idenfity outliers by stratum 
* ----------------------------------------------------------------------------
* create log of unit values
gen double lnuv = ln(uv)

* set threshold to identify outliers (here is 95%)
local sigma 1.96

gen byte flag_right=0
gen byte flag_left=0

qui levelsof foodid, local(food)
foreach f of local food {
			
	qui levelsof strata, local(strata)
	foreach s of local strata {

		qui sum lnuv [aw=weight] if uv>0 & !mi(uv) & strata == `s' & foodid==`f'
			
		* When the variance of unit value isgreater than zero we detect and delete outliers
		if r(Var) ~= 0 & r(Var) ~=. {
		
			local what: label (foodid) `f'
			dis in yellow "(`f') - `what'"
			
			qui sum lnuv [aw=weight] if uv>0 & !mi(uv) & strata == `s' & foodid==`f'
			loc amean_`f' = r(mean)	
			loc asd_`f' = r(sd)
			
			replace  uv = . if (abs((lnuv - `amean_`f'') / `asd_`f'') > `sigma') & strata == `s' & foodid==`f' & !mi(lnuv)
			
			qui replace flag_right = 1 if (((lnuv - `amean_`f'') / `asd_`f'') > `sigma')  & strata == `s' & foodid==`f' & !mi(lnuv)
			qui replace flag_left  = 1 if (((lnuv - `amean_`f'') / `asd_`f'') < -`sigma') & strata == `s' & foodid==`f' & !mi(lnuv)
		}	
	}
}


* Distribution of outliers by item

tab foodid if (flag_left == 1 | flag_right == 1), sort

tab foodid if flag_right == 1, sort
tab foodid if flag_left == 1, sort

tab flag_right, m
tab flag_left, m

/*
* visual inspection
set more on
qui levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	qui sum lnuv if foodid == `f', d
	if r(N) > 5 {
		kdensity lnuv /*[aw=weight]*/ if foodid == `f' & S5_B04B == 1, title("`what' - (`f')")
		more
	}	
}
set more off
*/

drop flag_right flag_left 
drop lnuv
drop x_purchase

* ----------------------------------------------------------------------------
* Impute missing unit values: cluster --> district --> region --> strata

* Note we use hh-level unit values when available
gen double uprice=uv

* Imputation level 1: impute CLUSTER median values
* count total number of hh per cluster
bysort cluster foodid: egen Nhh=count(foodid)

* Note: we require at least 3 households in each cluster 
*       for imputing the median uv of the cluster

qui levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	qui levelsof cluster, local(cluster)
	foreach c of local cluster {
		qui sum uv if foodid == `f' & cluster == `c', d
		local yes = r(N)
		if `yes' > 0 {
			qui sum uv if foodid == `f' & cluster == `c', d
			local cuv`f' = r(p50)
			replace uprice = `cuv`f'' if mi(uprice) & foodid == `f' & cluster == `c' & Nhh >= 3
		}
	}
}

* Imputation level 2: impute DISTRICT median values

qui levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	qui levelsof district, local(district)
	foreach d of local district {
		qui sum uv [aw=weight] if foodid == `f' & district == `d', d
		local yes = r(N)
		if `yes' > 0 {
			qui sum uv [aw=weight] if foodid == `f' & district == `d', d
			local cuv`f' = r(p50)
			replace uprice = `cuv`f'' if mi(uprice) & foodid == `f' & district == `d'
		}
	}
}

* Imputation level 3: impute REGION median values

qui levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	qui levelsof region, local(region)
	foreach r of local region {
		qui sum uv [aw=weight] if foodid == `f' & region == `r', d
		local yes = r(N)
		if `yes' > 0 {
			qui sum uv [aw=weight] if foodid == `f' & region == `r', d
			local cuv`f' = r(p50)
			replace uprice = `cuv`f'' if mi(uprice) & foodid == `f' & region == `r'
		}
	}
}


* Imputation level 4: impute STRATUM median values
* NOTE: regions and strata overlap - maybe we can jump from level 2 to level 4 

qui levelsof foodid, local(food)
foreach f of local food {
	local what: label (foodid) `f'
	dis in yellow "(`f') - `what'"
	qui levelsof strata, local(stratum)
	foreach s of local stratum {
		qui sum uv [aw=weight] if foodid == `f' & strata == `s', d
		local yes = r(N)
		if `yes' > 0 {
			qui sum uv [aw=weight] if foodid == `f' & strata == `s', d
			local cuv`f' = r(p50)
			replace uprice = `cuv`f'' if mi(uprice) & foodid == `f' & strata == `s'
		}
	}
}

assert !mi(uprice) | uprice >0

* ----------------------------------------------------------------------------
* 4. Calculate FOOD CONSUMPTION AGGREGATE 
* ----------------------------------------------------------------------------

* value of purchased food items
clonevar x_purch=S5_B05

* estimated value of purchases
* only for comparisons with S5_B05
gen double x_purch_check=0
replace x_purch_check=S5_B04A*uprice

* estimate value of own-production
gen double x_self=0
replace x_self=S5_B06A*uprice

* estimate value of own-production
gen double x_gift=0
replace x_gift=S5_B07A*uprice

* estimate total value of food consumption (only for consistency check)
gen double xfood = S5_B03A*uprice

* estimate total value of food consumption
gen double xfood_check = x_purch_check + x_self + x_gift

* ----------------------------------------------------------------------------
* Converting all weekly to monthly expenditure 

replace xfood=xfood*((365/12)/7)
lab var xfood "Total expenditure on food consumption (1,000 shillings/household/month)"

replace x_purch=x_purch*((365/12)/7)
lab var x_purch "Total value of food consumption out of gifts (1,000 shillings/household/month)"

replace x_purch_check=x_purch_check*((365/12)/7)
lab var x_purch_check "Estimated value of food consumption out of gifts (1,000 shillings/household/month)"

replace x_self=x_self*((365/12)/7)
lab var x_self "Total value of food consumption out of self-production (1,000 shillings/household/month)"

replace x_gift=x_gift*((365/12)/7)
lab var x_gift "Total value of food consumption out of gifts (1,000 shillings/household/month)"

replace xfood_check=xfood_check*((365/12)/7)
lab var xfood_check "Total expenditure on food consumption (1,000 shillings/household/month)"

sum  x* [aw=weight]
sum  x* 


*Decide which version of the pipeline should be run
if ($run2016vs2013==1) {
	*Drop items to make 2012 and 2016 comparable 
	drop if S5_FOOD_CONSUPTION=="Coconuts" | S5_FOOD_CONSUPTION=="Dried or salted meat" | S5_FOOD_CONSUPTION=="Groundnuts shelled" | S5_FOOD_CONSUPTION=="Other 'Roots, Tubers" | S5_FOOD_CONSUPTION=="Other vegetables (sp"  
}


save "${gsdData}/1-CleanTemp/food_consumption_clean.dta", replace

