*estimates the consumption flow from durable goods

set more off

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

use "${gsdData}/1-CleanInput/data_12_proc_for_later.dta", clear

keep if (durablesid>=501 & durablesid<=536)

* ----------------------------------------------------------------------------
* Calculating purchased and current prices of durables
* ----------------------------------------------------------------------------
	
* Calculating purchased price of durable items
* NOTE: Market exchange rate at the moment of survey data collection was 
* 6,850 Schilling=1 USD. There is one observation whose unit is 
* apparently in USD

gen purchased_price=.
replace	purchased_price=S12_F05/1000 		if S12_F05_U==1
replace purchased_price=S12_F05		 		if S12_F05_U==2
replace purchased_price=S12_F05*1000 		if S12_F05_U==3
replace purchased_price=S12_F05*6850/1000 	if S12_F05_U==4

* -->37 observations that did not paid anything for the item (received durable as gift perhaps?)
replace purchased_price=. if S12_F05==0

* -->19 observations with irrelevant data (refused, don't know, and missings)
* GV: hmmm, double check later
replace purchased_price=. if S12_F05==97
replace purchased_price=. if S12_F05==98
replace purchased_price=. if S12_F05==99

* Calculating current price of durable items
gen double current_price=.
replace	current_price=S12_F06/1000 	if S12_F06_U==1
replace current_price=S12_F06 		if S12_F06_U==2
replace current_price=S12_F06*1000 	if S12_F06_U==3

*-->12 observations with irrelevant data (don't know and missings)
replace current_price=. if S12_F06==98
replace current_price=. if S12_F06==99

* ----------------------------------------------------------------------------
* Calculating vintages of durable items

* -->I add a one here so that item purchased in 2013 is one year old. 
* I do this as otherwise when I use depreciation formula values become missing 
* for items purchased this year and I assume that just by taking item out of 
* the store items losses value

gen double	vintage= (2013-S12_F04)+1
replace 	vintage=. if S12_F04==.
replace 	vintage=. if S12_F04==99 
replace 	vintage=. if S12_F01==2

* Adjusting vintage for items with missing year of purchase information 
* (21 observations with missing purchased year)

bysort strata durablesid: egen medianvintage=median(vintage)

replace vintage=medianvintage if S12_F04==99 & S12_F01==1

table durablesid if S12_F01==1, c(mean vintage median vintage min vintage max vintage count vintage) m format(%9.1f)

drop medianvintage

* ----------------------------------------------------------------------------
* Calculating preliminary depreciation rates by item for each household 
* as a way of identifying mistakes 

* Setting key parameters for cash flow calculation

* Set inflation rate (ASSUMPTION)
* http://www.fsnau.org/products/bulletins/market-data-update  reports - 
* 9% of price changes over previous year in July 2013
* our guess on the inflation rate required to implement eq. (), p. in 
* Deaton and Zaidi (2002). Note: we use here the "exact" formula, not its
* approximated version
local pi = 0.005

* Set nominal interest rate (ASSUMPTION)
local i = 0.02

gen double drate=1 -(1/(1+`pi'))*(current_price/purchased_price)^(1/vintage)

* 2) Inspect depreciation rates (check for regional disparities and outliers, always look at medians)
*table durablesid, c(mean drate median drate min drate max drate count drate) format (%9.4f)
*table S12_STRATA, c(mean drate median drate min drate max drate count drate) format (%9.4f)

* 3) Clean outliers and errors

* a) First round 
*   (data entry mistakes: different units for purchased and current prices, 25 observations)

replace S12_F05_U=S12_F06_U if drate<0 & S12_F05_U<S12_F06_U

drop drate current_price purchased_price

g 		purchased_price=.
replace	purchased_price=S12_F05/1000 	if S12_F05_U==1
replace purchased_price=S12_F05 		if S12_F05_U==2
replace purchased_price=S12_F05*1000	if S12_F05_U==3
replace purchased_price=. if S12_F05==0
replace purchased_price=. if S12_F05==97
replace purchased_price=. if S12_F05==98
replace purchased_price=. if S12_F05==99

g 		current_price=.
replace	current_price=S12_F06/1000 	 	if S12_F06_U==1
replace current_price=S12_F06	 		if S12_F06_U==2
replace current_price=S12_F06*1000	 	if S12_F06_U==3
replace current_price=. if S12_F06==98
replace current_price=. if S12_F06==99

gen double drate=1 -(1/(1+`pi'))*(current_price/purchased_price)^(1/vintage)

table durablesid if drate<0, c(min drate mean drate max drate count drate) format(%9.1f) row

* b) Second round (drate cannot be negative, 58 obs.)
replace drate=0 if drate<0

* 4) Calculate median depreciation rates across households by item
*    to replace for drate missing values replaced above 
*    (I do not do this by strata as few households own durables overall) 

gen dratem=.

levelsof durablesid, local(durable)

foreach dur of local durable {
	di in ye "the good is " `dur'
		*qui sum drate [aw=weight]  if durable_code==`dur', detail
		qui sum drate 				if durablesid==`dur', detail
		qui replace dratem=r(p50)   if durablesid==`dur' & dratem==.

	}

*replace drate=dratem if flag==1

* 5) Replacing median depreciation rates for households who report no purchased 
*    or current value for the item but own the item (58 observations) 

replace drate=dratem if drate==. & S12_F01==1
lab var drate "Depreciation rate for each durable item by household"

tab dratem if S12_F01==1, m

lab var dratem "Median depreciation rate for each durable item"

g proportionowning=100*(S12_F01==1)

table durablesid [aw=weight], c(median dratem mean proportionowning) format (%9.4f)
qui tabout durablesid [aw=weight] using "${gsdOutput}/Table04.xls", sum c(median dratem mean proportionowning) f(3c 1c) replace

* ----------------------------------------------------------------------------
* Cleaning number of items owned

* Cleaning (5 households report having durable but not how many items they own
* I replace them with median value)

g 		nowned=S12_F03
replace nowned=. if nowned==99 & S12_F01==1 

levelsof durablesid, local(durable)

foreach dur of local durable {
	di in ye "the good is " `dur'
	*qui sum drate [aw=weight]  if durable_code==`dur', detail
	qui sum nowned 				if durablesid==`dur' & S12_F01==1, detail
	qui replace nowned=r(p50)   if durablesid==`dur' & S12_F01==1 & nowned==. 

}

* ----------------------------------------------------------------------------
* Calculating consumption flow (will be valid only later for households
* that own only one item of each durable)

gen double cf = current_price*(`i' - `pi' + dratem) if S12_F01==1


*Decide which version of the pipeline should be run
if ($run2016vs2013==1) {
	*Drop consumption flow estimate for the next 12 months
	drop cf
	*Estimate consumption flow for the previous 12 months 
	gen double cf = (current_price/(1 - dratem + `pi'))*(`i' - `pi' + dratem)  if S12_F01==1
}


* note: annual values are being used here
table durablesid [aw=weight] if S12_F03==1, c(median dratem mean proportionowning mean cf) format (%9.4f)

* ----------------------------------------------------------------------------
* Calculating median consumption flow -- will be used to estimate CF 
* for households that own more than one item of each durable 

* Get median cash flow for each durable using data. 
* I wanted to get median cash flow using only households that bought item 
* before household did but sample is small and we have 35 different vintages.

* If larger number of durable items owned are concentrated in the very rich, 
* adjustments for the second and third durable goods will not affect much 
* for poverty incidence but affect some for inequality. 

gen double cf_1=.
levelsof vintage, local(vintagelist)
foreach dur of local durable {
	foreach vin of local vintagelist {
		dis in green "the good is " in ye `dur' in green " and vintage is " in ye `vin'
		qui sum cf 				if durablesid==`dur' & S12_F01==1 & vintage>`vin', d
		qui replace cf_1=r(p50) if durablesid==`dur' & S12_F01==1 & vintage==`vin'
	}
}

gen 	cfbar=cf_1 		if nowned>=2 & S12_F01==1
lab var cfbar "Median cash flow for items with missing information on purchased year and amount paid"

* ----------------------------------------------------------------------------
* Calculating final consumption flow

gen 	durables = current_price*(`i' - `pi' + dratem) 					 	if S12_F01==1 & nowned==1 
replace durables = current_price*(`i' - `pi' + dratem) + ((nowned-1)*cfbar)	if S12_F01==1 & nowned>=2


*Decide which version of the pipeline should be run
if ($run2016vs2013==1) {
	*Drop consumption flow estimate for the next 12 months
	drop durables
	*Estimate consumption flow for the previous 12 months 
	gen 	durables = (current_price/(1 - dratem + `pi'))*(`i' - `pi' + dratem) 			            if S12_F01==1 & nowned==1 
	replace durables = (current_price/(1 - dratem + `pi'))*(`i' - `pi' + dratem) + ((nowned-1)*cfbar)	if S12_F01==1 & nowned>=2
}


replace durables=0 if S12_F01==2

* ----------------------------------------------------------------------------
* NEW CODE - CLEANING OUTLIERS IN CF

* set threshold to identify outliers (here is 95%)
local sigma 1.96

gen lndur=ln(durables)
gen byte flag = 0

qui levelsof durablesid, local(dur)
foreach d of local dur {
		
	qui sum lndur [aw=weight] if durables>0 & !mi(durables) & durablesid==`d'
			
	* When the variance of unit value isgreater than zero we detect and delete outliers
	if r(Var) ~= 0 & r(Var) ~=. {
		
		local what: label (durablesid) `d'
		dis in yellow "(`d') - `what'"
			
		qui sum lndur [aw=weight] if durables>0 & !mi(durables) & durablesid==`d'
		loc amean_`f' = r(mean)	
		loc asd_`f' = r(sd)
			
		replace  durables = . if (abs((lndur - `amean_`f'') / `asd_`f'') > `sigma') & durablesid==`d' & !mi(lndur)
			
		qui replace  flag = 1 if (abs((lndur - `amean_`f'') / `asd_`f'') > `sigma') & durablesid==`d' & !mi(lndur)
	}	
}


* Distribution of outliers by item
tab durablesid if flag == 1, sort

* Replace outliers

qui levelsof durablesid, local(dur)
foreach d of local dur {
	local what: label (durablesid) `d'
	dis in yellow "(`d') - `what'"

	_pctile durables [aw=weight] if durables>0 & durablesid==`d', p(50)
	replace durables = r(r1) if flag==1 & durables==. & durablesid==`d'			
}

* transform per year in per month
replace durables=durables/12
lab var durables "Consumption flow of durables (1,000 Shillings/household/month)"

save "${gsdData}/1-CleanTemp/durables_clean.dta", replace
