*Real consumption aggregate

set more off


*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}

* ----------------------------------------------------------------------------
* 1. Bring in various components

use "${gsdData}/1-CleanTemp/food_consumption_clean.dta", clear

collapse (sum) x* (firstnm) weight district region strata cluster, by(hhid)

save "${gsdData}/1-CleanTemp/delmefood.dta", replace

* Nonfood expenditures 

use "${gsdData}/1-CleanTemp/non_food_clean.dta", clear

collapse (sum) xnonfood, by(hhid)

save "${gsdData}/1-CleanTemp/delmenonfood.dta", replace

* Durables

use "${gsdData}/1-CleanTemp/durables_clean.dta", clear

collapse (sum) durables, by(hhid)

save "${gsdData}/1-CleanTemp/delmedurables.dta", replace

* Put all components together 

use "${gsdData}/1-CleanTemp/delmefood.dta", clear
merge 1:1 hhid using "${gsdData}/1-CleanTemp/delmenonfood.dta"
assert _merge == 3
drop _merge
drop x*check

merge 1:1 hhid using "${gsdData}/1-CleanTemp/delmedurables.dta"
assert _merge  !=2
drop _merge

* ----------------------------------------------------------------------------
* 2. Bring in spatial price indices
gen byte urban = .
replace urban = 1 if strata == 1 | strata == 3
replace urban = 0 if strata == 2
label var urban " = 1 if urban, o if rural"
label def urban 1 "urban" 0 "rural"
label val urban urban

* use paasche at the district level (democratic)
merge m:1 district urban using "${gsdData}/1-CleanTemp/paasche_r.dta", keepusing(paasche_r)
drop _merge
merge m:1 district urban using "${gsdData}/1-CleanTemp/paasche_u.dta", keepusing(paasche_u)
drop _merge

gen paasche = . 
replace paasche = paasche_u if urban == 1 
replace paasche = paasche_r if urban == 0
drop paasche_r
drop paasche_u

* ----------------------------------------------------------------------------
* 3. Generate nominal and real consumption aggregates

gen double the = xfood + xnonfood + durables


*Decide which version of the pipeline should be run
if ($run2016vs2013==1) {
	*Correctly generate the consumption aggregate 
	drop the 
	egen the =rowtotal(xfood xnonfood durables)
}


label var the "Nominal consumption aggregate (1,000 Shillings/household/month)"

gen rthe = the/paasche
label var rthe "Real consumption aggregate (1,000 Shillings/household/month)"

* bring in household size and transform in per capita terms
merge 1:1 hhid using "${gsdData}/1-CleanInput/hh.dta", keepusing(S1_HHSIZE)
assert _merge == 3
drop _merge
ren S1_HHSIZE hsize

gen pce =  the/hsize
label var pce "Nominal consumption aggregate (1,000 Shillings/person/month)"

gen rpce = rthe/hsize
label var rpce "Real consumption aggregate (1,000 Shillings/person/month)"

* data housekeeping
lab var xfood "Nominal expenditure on food consumption (1,000 shillings/household/month)"
lab var x_purch "Nominal value of food consumption out of gifts (1,000 shillings/household/month)"
lab var x_self "Nominal value of food consumption out of self-production (1,000 shillings/household/month)"
lab var x_gift "Nominal value of food consumption out of gifts (1,000 shillings/household/month)"
lab var xnonfood "Nominal expenditure on nonfood consumption (1,000 shillings/household/month)"
ren durables xdurables
lab var xdurables "Nominal consumption flow of durables (1,000 shillings/household/month)" 

* real variables (per hh)
gen rfood = (xfood/paasche)
gen rnonfood = (xnonfood/paasche)
gen rdurables = (xdurables/paasche)

lab var rfood "Real expenditure on food consumption (1,000 shillings/household/month)"
lab var rnonfood "Real expenditure on nonfood consumption (1,000 shillings/household/month)"
lab var rdurables "Real consumption flow of durables (1,000 shillings/household/month)" 

* per capita variables
** nominal
gen xfood_pc = xfood/hsize
gen xnonfood_pc = xnonfood/hsize
gen xdurables_pc = xdurables/hsize

lab var xfood_pc "Nominal expenditure on food consumption (1,000 shillings/person/month)"
lab var xnonfood_pc "Nominal expenditure on nonfood consumption (1,000 shillings/person/month)"
lab var xdurables_pc "Nominal consumption flow of durables (1,000 shillings/person/month)" 

** real
gen rfood_pc = (xfood/paasche)/hsize
gen rnonfood_pc = (xnonfood/paasche)/hsize
gen rdurables_pc = (xdurables/paasche)/hsize

lab var rfood_pc "Real expenditure on food consumption (1,000 shillings/person/month)"
lab var rnonfood_pc "Real expenditure on nonfood consumption (1,000 shillings/person/month)"
lab var rdurables_pc "Consumption flow of durables (1,000 shillings/person/month)" 

order x* r*, alpha
order hhid-strata, before(rdurables)
order region, before(district)
order hsize, before(rdurables)
order paasche, before(rdurables)
order pce, before(rpce)

label val district DIST
label val strata STRATA

save "${gsdData}/1-CleanTemp/wfile.dta", replace

* -----------------------------------------------------------------------------  
* Figure 4 - PDFs RURAL & URBAN
use  "${gsdData}/1-CleanTemp/wfile.dta", clear

qui su rpce
local N = r(N)

kdensity rpce [aw=weight*hsize] if urban == 1, generate(x1r fx1r) n(`N') nograph
kdensity rpce [aw=weight*hsize] if urban == 0, generate(x2r fx2r) n(`N') nograph

qui su rpce [aw=weight*hsize], d
local lthan = r(p95)

*graph twoway (line fx1r x1r if x1r<`lthan', sort lw(medthick) lcol(dknavy)) ///
			 (line fx2r x2r if x2r<`lthan', lcol(red*1.1) lw(medthick) lp(dash) sort), ///
              ylab(,angle(h)) ytit("Number of people" "(density)") ///
              legend(label(1 "Urban") label(2 "Rural") ring(0) col(1) pos(1)) ///
              xtit("Per Capita Expenditure" "(1,000 shillings/person/month)") xlab() ///
              graphregion(fcolor(white)) 


* -----------------------------------------------------------------------------  
* Figure 5 - CDFs by urban
use  "${gsdData}/1-CleanTemp/wfile.dta", clear
levelsof urban, local(urb)
qui su rpce
local N = r(N)

foreach u of local urb {
	
	qui su rpce [aw=weight*hsize] if urban == `u', d
	local lthan = r(p99)
	
	cumul rpce [aw=weight*hsize] if urban == `u' & rpce<`lthan', gen(Fpce`u')
	 
	replace Fpce`u' = Fpce`u' * 100	
}

*twoway (line Fpce1 rpce if rpce <`lthan', lw(medthick) lcol(black) sort) ///
	   (line Fpce0 rpce if rpce <`lthan', lw(medthick) lcol(red*1.1) sort) ///
       , scheme(sj)  legend(label(1 "Urban") label(2 "Rural") ring(0) col(1) pos(5)) ///
       graphregion(fcolor(white)) ///
       ylab(,angle(0)) ytit("Cumulative Population" "(%)") ///
       xtick() xtit("Real Per Capita Expenditure" "(1,000 shillings/person/month)") xlab()

* -----------------------------------------------------------------------------
* Tables 6 in the paper

use "${gsdData}/1-CleanTemp/wfile.dta", clear
* consumption aggregates
gen double popwt=weight*hsize
*table urban [aw=weight*hsize], c(mean pce mean rpce) format(%9.1f) row
*qui tabout urban [aw=popwt] using Table06a.xls, sum c(mean pce median pce mean rpce median rpce) f(4c 4c) replace
*table district [aw=weight*hsize], c(mean pce mean rpce) format(%9.0f) row 
*qui tabout district [aw=popwt] using Table06b.xls, sum c(mean pce median pce mean rpce median rpce) f(4c 4c) replace
* rural
tabstat pce rpce [aw=weight*hsize] if !urban, by(district) format(%9.0f) s(median)
tabstat pce rpce [aw=weight*hsize] if !urban, by(district) format(%9.0f) s(mean)
* urban
tabstat pce rpce [aw=weight*hsize] if urban, by(district) format(%9.0f) s(median)
tabstat pce rpce [aw=weight*hsize] if urban, by(district) format(%9.0f) s(mean)

* real per capita expenditures
table urban [aw=weight*hsize], c(mean rfood_pc mean rnonfood_pc mean rdurables_pc mean rpce) format(%9.1f) row
qui tabout urban [aw=popwt] using  "${gsdOutput}/Table07a.xls", sum c(mean xfood_pc mean xnonfood_pc mean xdurables_pc mean rpce) f(4c 4c 4c) replace
table district [aw=weight*hsize], c(mean rfood_pc mean rnonfood_pc mean rdurables_pc mean rpce) format(%9.1f) row
qui tabout district [aw=popwt] using "${gsdOutput}/Table07b.xls", sum c(mean xfood_pc mean xnonfood_pc mean xdurables_pc  mean rpce) f(4c 4c 4c) replace

* -----------------------------------------------------------------------------
* Table 7
* rural
use "${gsdData}/1-CleanTemp/wfile.dta", clear
preserve
keep if !urban
* ad-hoc fix for two crazy values
su  xdurables_pc if district == 24, d
replace xdurables_pc = r(p90) if district == 24 & xdurables_pc>=r(p95)
su  xdurables_pc if district == 24, d
su  xdurables_pc if district == 52, d
replace xdurables_pc = r(p90) if district == 52 & xdurables_pc>=r(p95)
su  xdurables_pc if district == 52, d

*tabstat xfood_pc xnonfood_pc xdurables_pc rpce [aw=weight*hsize], by(district) format(%9.1f) s(mean)
tabstat rfood_pc rnonfood_pc rdurables_pc rpce [aw=weight*hsize], by(district) format(%9.1f) s(mean)
restore

* urban
use "${gsdData}/1-CleanTemp/wfile.dta", clear
preserve
keep if urban

tabstat rfood_pc rnonfood_pc rdurables_pc rpce [aw=weight*hsize], by(district) format(%9.1f) s(mean)
restore

* -----------------------------------------------------------------------------
* FIGURE 7
use "${gsdData}/1-CleanTemp/wfile.dta", clear

gen w_food = 100*(rfood_pc/rpce)
gen w_nonfood = 100*(rnonfood_pc/rpce)
gen w_durab = 100-w_food-w_nonfood

*graph bar w_food w_nonfood w_durab [aw=weight*hsize], over(urban) ///
	graphregion(fcolor(white)) blabel(bar, format(%9.1f)) ///
	legend(label(1 "Food") label(2 "Nonfood") label(3 "Durables") ring(0) pos(2) col(1) size(*.8)) ///
	ylab(, angle(0))

* -----------------------------------------------------------------------------	
* INEQUALITY

capture drop prl
glcurve rpce [aw = weight*hsize], lorenz pvar(prl) glvar(rl) ///
       by(urban) split nograph

lab var prl "Cumulative population share"
replace prl = prl*100
replace rl_1 = rl_1*100
replace rl_0 = rl_0*100
lab var rl_1 "Urban" 
lab var rl_0 "Rural"
   
sort prl 
*graph twoway (line rl_1 prl, yaxis(1 2) lp(solid) lw(medthick) ) ///
             (line rl_0 prl, yaxis(1 2) lp(dash) lw(medthick) ) ///
             (function y = x, range(0 100) yaxis(1 2) ) ///
           , aspect(1) xtit("Population" "(cumulative %)") ///
             ytitle("Share of total PCE" "(%)", axis(1)) ///
             ytitle(" ", axis(2)) ylab(, angle(0) axis(1)) ylab(, angle(0) axis(2)) ///
             legend(label(1 "Urban") label(2 "Rural") label(3 "Equality") ///
             region(lstyle(none)) ring(0) pos(11) col(1) size(*.9) symysize(*.7) bm(large)) ///
             graphregion(fcolor(white)) scheme(sj) ///
             tit(" ")

ineqdeco rpce [aw=weight*hsize], by(strata)

