*estimation of poverty lines Given the inability to aggregate urban and rural hhs due to differences in sampling design we decide to estimate two poverty lines
	
set more off

*Check if filepaths have been established using init.do
if "${gsdData}"=="" {
	display as error "Please run init.do first."
	error 1
}


*	The plan:
*	---------
*
*	1. Set Average Kilocalorie Requirement
*	2. Estimate unit cost of kilocalorie
*	3. Estimate Food Poverty Line
*	4. Estimate Non-food Allowance (upper and lower bounds)
*	5. Calculate total poverty line


* ----------------------------------------------------------------------------
* 1. Set Average Kilocalorie Requirement

local AKR 2100 

* Descriptive statistics for kilocalories/person/day

* ----------------------------------------------------------------------------
* 2. Estimate unit cost of kilocalorie
*    We do so separately by urban-rural 

use "${gsdData}/1-CleanTemp/wfile.dta", clear
merge 1:1 hhid using "${gsdData}/1-CleanTemp/kcal_dn.dta"
assert _merge == 3
drop _merge

* create real PCE deciles and quintiles, separately by urban-rural
xtile rpcedec_u = rpce [aw=weight*hsize] if urban, nq(10)
xtile rpcedec_r = rpce [aw=weight*hsize] if !urban, nq(10)
xtile rpcequi_u = rpce [aw=weight*hsize] if urban, nq(5)
xtile rpcequi_r = rpce [aw=weight*hsize] if !urban, nq(5)

* kcal availability by quantile
tabstat kcal_tot [aw=weight*hsize] if urban, by(rpcequi_u)  format(%9.0f) s(mean median)
tabstat kcal_tot [aw=weight*hsize] if !urban, by(rpcequi_r)  format(%9.0f) s(mean median)

/* pdf

* FIGURE 8 in the paper

use wfile, clear
merge 1:1 hhid using kcal_dn
assert _merge == 3
drop _merge

qui su kcal_tot, d
local N = r(N)
local lthan = r(p95)
kdensity kcal_tot [aw=weight*hsize] if urban == 1, generate(xu fxu) n(`N') nograph
kdensity kcal_tot [aw=weight*hsize] if urban == 0, generate(xr fxr) n(`N') nograph


graph twoway (line fxu xu if xu<`lthan', sort lw(medthick) lcol(dknavy)) (line fxr xr if xr<`lthan', lcol(cranberry) lw(medthick) lp(dash) sort) ///
              (dropline fxu xu if round(xu,10)==2100,  lp(solid) lcol(black) ms(i)), ///
              ylab(,angle(h)) ytit ("Number of people" "(density)") legen(off) ///
              xtit("Kilocalories/person/day") xlab(0(500)6000, labsize(*.7)) ///
              graphregion(fcolor(white))

povdeco kcal_tot [aw=weight*hsize], pl(2100) by(urban)
*/

* kilocalorie unit cost
gen ukcal = (rfood/hsize)/(kcal_tot*365/12)

*
*table rpcedec [aw=weight], c(mean ukcal median ukcal min ukcal max ukcal) format(%9.4f) row
*table rpcequi [aw=weight], c(mean ukcal median ukcal min ukcal max ukcal) format(%9.4f) row
gen ukcal_000 = 1000*ukcal
tabstat ukcal_000 [aw=weight] if urban, by(rpcedec_u)  format(%9.1f) s(mean median)
tabstat ukcal_000 [aw=weight] if !urban, by(rpcedec_r)  format(%9.1f) s(mean median)
tabstat ukcal_000 [aw=weight] if urban, by(rpcequi_u)  format(%9.1f) s(mean median)
tabstat ukcal_000 [aw=weight] if !urban, by(rpcequi_r)  format(%9.1f) s(mean median)

* reference group: bottom 40%
local refgroup 4

* urban
su ukcal [aw=weight] if urban & rpcedec_u<=`refgroup', d
local ukcal_u = r(p50)

* rural
su ukcal [aw=weight] if !urban & rpcedec_r<=`refgroup', d
*su ukcal [aw=weight] if rpcedec<=`refgroup', d
local ukcal_r = r(p50)

* ----------------------------------------------------------------------------
* 3. Estimate Food Poverty Line

gen zfood_u = (`AKR'*`ukcal_u')*(365/12)
label var zfood_u "urban food poverty line (1,000 shillings/person/day)"

gen zfood_r = (`AKR'*`ukcal_r')*(365/12)
label var zfood_r "rural food poverty line (1,000 shillings/person/day)"

* extreme poverty rates
su zfood*
povdeco rpce [aw=weight*hsize] if urban, varpl(zfood_u)
povdeco rpce [aw=weight*hsize] if !urban, varpl(zfood_r)
povdeco rfood_pc [aw=weight*hsize] if urban, varpl(zfood_u)
povdeco rfood_pc [aw=weight*hsize] if !urban, varpl(zfood_r)

* ----------------------------------------------------------------------------
* 3. Estimate Non-Food allowance  

* The second method  la Bidani and Ravallion
* the suffix "_a" stands for "additive" - see code below

* 3.1 LOWER BOUND
* Select a group of households whose TOTAL expenditure is equal (close)
* to the Food Poverty Line

* Interval
local range = 0.10

* urban
sum zfood_u
local zf_u = r(mean)
qui sum rnonfood_pc [aw=weight*hsize] if urban & rpce > (zfood_u * (1-`range')) & rpce < (zfood_u* (1+`range')), d
gen zlower_u = `zf_u' + r(p50) if urban
label var zlower_u "urban poverty line - lower bound (1000 shillings/person/month)"

* rural
sum zfood_r
local zf_r = r(mean)
qui sum rnonfood_pc [aw=weight*hsize] if !urban & rpce > (zfood_r * (1-`range')) & rpce < (zfood_r* (1+`range')), d
gen zlower_r = `zf_r' + r(p50) if !urban
label var zlower_r "rural poverty line - lower bound (1000 shillings/person/month)"

gen zlower =. 
replace zlower = zlower_u if urban
replace zlower = zlower_r if !urban
label var zlower "poverty line - lower bound (1000 shillings/person/month)"

* 3.2 UPPER BOUND
* Select a group of households whose FOOD expenditure is equal (close)
* to the Food Poverty Line

* Interval
local range = 0.10

* urban
sum zfood_u
local zf_u = r(mean)
qui sum rnonfood_pc [aw=weight*hsize] if urban & rfood_pc > (zfood_u * (1-`range')) & rfood_pc < (zfood_u* (1+`range')), d
gen zupper_u = `zf_u' + r(p50) if urban
label var zupper_u "urban poverty line - upper bound (1000 shillings/person/month)"

* rural
sum zfood_r
local zf_r = r(mean)
qui sum rnonfood_pc [aw=weight*hsize] if !urban & rfood_pc > (zfood_r * (1-`range')) & rfood_pc < (zfood_r* (1+`range')), d
gen zupper_r = `zf_r' + r(p50) if !urban
label var zupper_r "rural poverty line - upper bound (1000 shillings/person/month)"

gen zupper =. 
replace zupper = zupper_u if urban
replace zupper = zupper_r if !urban
label var zupper "poverty line - upper bound (1000 shillings/person/month)"

* housekeeping 
order urban, after(strata)
*order zfood, before(ztot)
*drop ztot zlower zupper
*ren zlower_a zlower
*ren zupper_a zupper
*ren ztot_a ztot 
*drop zlower_nat zupper_nat zlower_nat_a zupper_nat_a ztot_nat_a

save "${gsdData}/1-CleanTemp/wfilez.dta", replace


** KEY DESCRIPTIVE STATISTICS
* poverty lines by stratum
tabstat z*_u if urban, s(mean) format(%9.1f) c(v)
tabstat z*_r if !urban, s(mean) format(%9.1f) c(v)


* kcal by PCE quantiles
*table rpcedec_u [aw=weight*hsize], c(mean kcal_tot median kcal_tot) format(%9.0f) row
*table rpcequi urban [aw=weight*hsize], c(mean kcal_tot) format(%9.0f) row col

* avg real PCE by real	 PCE quantiles
*table rpcedec [aw=weight*hsize], c(mean rpce median rpce) format(%9.1f) row
*table rpcequi [aw=weight*hsize], c(mean rpce median rpce) format(%9.1f) row

* poverty rates
*povdeco rpce [aw=weight*hsize] if urban, varpl(zfood_u)
*povdeco rpce [aw=weight*hsize] if urban, varpl(zlower_u)
povdeco rpce [aw=weight*hsize] if urban, varpl(zupper_u)
*povdeco rpce [aw=weight*hsize] if !urban, varpl(zfood_r)
*povdeco rpce [aw=weight*hsize] if !urban, varpl(zlower_r)
povdeco rpce [aw=weight*hsize] if !urban, varpl(zupper_r)

*poverty line (Thousands of Somaliland Shilling per person per day)
*based on 1.9 USD PPP in 2013 prices for Somaliland 
gen x=10.6801112312 
*convert it to monthly 
gen new_pline=(x*365)/12
povdeco rpce [aw=weight*hsize] if urban, varpl(new_pline)
povdeco rpce [aw=weight*hsize] if !urban, varpl(new_pline)

capture: drop poor pgap psev
local pline = "zlower"
gen poor = rpce < `pline'
gen pgap = (`pline' - rpce) / `pline'
replace pgap = 0 if pgap <0
gen psev = pgap^2

mean poor pgap psev [pweight=weight*hsize], over(urban)
